Index: sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart |
diff --git a/sdk/lib/_internal/pub/test/get/git/lock_version_test.dart b/sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart |
similarity index 81% |
copy from sdk/lib/_internal/pub/test/get/git/lock_version_test.dart |
copy to sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart |
index 0d764576155b5a3639e47bf47d7b021edc574297..137e38414cae1301a8ae884c82c754a592299c1e 100644 |
--- a/sdk/lib/_internal/pub/test/get/git/lock_version_test.dart |
+++ b/sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart |
@@ -11,9 +11,11 @@ import '../../../lib/src/io.dart'; |
import '../../descriptor.dart' as d; |
import '../../test_pub.dart'; |
+// Regression test for issue 16470. |
+ |
main() { |
initConfig(); |
- integration('keeps a Git package locked to the version in the lockfile', () { |
+ integration('checks out the repository for a locked revision', () { |
ensureGit(); |
d.git('foo.git', [ |
@@ -32,8 +34,10 @@ main() { |
]) |
]).validate(); |
// Delete the packages path to simulate a new checkout of the application. |
schedule(() => deleteEntry(path.join(sandboxDir, packagesPath))); |
+ schedule(() => deleteEntry(path.join(sandboxDir, cachePath))); |
d.git('foo.git', [ |
d.libDir('foo', 'foo 2'), |
@@ -32,8 +34,10 @@ main() { |
]) |
]).validate(); |
- // Delete the packages path to simulate a new checkout of the application. |
+ // Delete the packages path and the cache to simulate a brand new checkout |
+ // of the application. |
schedule(() => deleteEntry(path.join(sandboxDir, packagesPath))); |